@@ -2,8 +2,8 @@
  *
  * NOTIFICATIONS.C - Nagios Notifications CGI
  *
- * Copyright (c) 1999-2004 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 10-30-2004
+ * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 10-09-2006
  *
  * This CGI program will display the notification events for 
  * a given host or contact or for all contacts/hosts.
@@ -154,7 +154,7 @@ int main(void){
 				printf("<A HREF='%s?host=%s'>View History For %s</A><BR>\n",HISTORY_CGI,(find_all==TRUE)?"all":url_encode(query_host_name),(find_all==TRUE)?"All Hosts":"This Host");
 #ifdef USE_TRENDS
 				if(find_all==FALSE)
-					printf("<A HREF='%s?host=%s'>View Trends For This Host</A><BR>\n",HISTORY_CGI,url_encode(query_host_name));
+					printf("<A HREF='%s?host=%s'>View Trends For This Host</A><BR>\n",TRENDS_CGI,url_encode(query_host_name));
 #endif
 	                        }
 			else if(query_type==FIND_SERVICE){
@@ -290,16 +290,16 @@ void document_header(int use_stylesheet){
 	time_t current_time;
 	time_t expire_time;
 
-	printf("Cache-Control: no-store\n");
-	printf("Pragma: no-cache\n");
+	printf("Cache-Control: no-store\r\n");
+	printf("Pragma: no-cache\r\n");
 
 	time(&current_time);
 	get_time_string(&current_time,date_time,(int)sizeof(date_time),HTTP_DATE_TIME);
-	printf("Last-Modified: %s\n",date_time);
+	printf("Last-Modified: %s\r\n",date_time);
 
 	expire_time=(time_t)0L;
 	get_time_string(&expire_time,date_time,(int)sizeof(date_time),HTTP_DATE_TIME);
-	printf("Expires: %s\n",date_time);
+	printf("Expires: %s\r\n",date_time);
 
 	printf("Content-type: text/html\r\n\r\n");
 
@@ -553,7 +553,7 @@ void display_notifications(void){
 			/* get the host name */
 			temp_buffer=(char *)strtok(NULL,";");
 			snprintf(host_name,sizeof(host_name),"%s",(temp_buffer==NULL)?"":temp_buffer);
-			host_name[sizeof(host_name)]='\x0';
+			host_name[sizeof(host_name)-1]='\x0';
 
 			/* get the service name */
 			if(notification_type==SERVICE_NOTIFICATION){
