@@ -2,8 +2,8 @@
  *
  * STATUSMAP.C - Nagios Network Status Map CGI
  *
- * Copyright (c) 1999-2004 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 01-19-2004
+ * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 03-21-2006
  *
  * Description:
  *
@@ -13,9 +13,8 @@
  * License:
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,16 +27,14 @@
  *
  *****************************************************************************/
 
-#include "../common/config.h"
-#include "../common/locations.h"
-#include "../common/common.h"
-#include "../common/objects.h"
-#include "../common/statusdata.h"
+#include "../include/config.h"
+#include "../include/common.h"
+#include "../include/objects.h"
+#include "../include/statusdata.h"
 
-#include "cgiutils.h"
-#include "getcgi.h"
-#include "auth.h"
-#include "edata.h"
+#include "../include/cgiutils.h"
+#include "../include/getcgi.h"
+#include "../include/cgiauth.h"
 
 #include <gd.h>			/* Boutell's GD library function */
 #include <gdfonts.h>		/* GD library small font definition */
@@ -56,11 +53,11 @@ extern char url_images_path[MAX_FILENAME_LENGTH];
 extern char url_logo_images_path[MAX_FILENAME_LENGTH];
 extern char url_stylesheets_path[MAX_FILENAME_LENGTH];
 
-extern hostgroup *hostgroup_list;
-extern hoststatus *hoststatus_list;
 extern host *host_list;
-extern servicestatus *servicestatus_list;
+extern hostgroup *hostgroup_list;
 extern service *service_list;
+extern hoststatus *hoststatus_list;
+extern servicestatus *servicestatus_list;
 
 extern char *statusmap_background_image;
 
@@ -217,7 +214,6 @@ int nagios_icon_x=0;           /* coords of Nagios icon */
 int nagios_icon_y=0;
 
 extern hostextinfo *hostextinfo_list;
-extern host *host_list;
 extern hoststatus *hoststatus_list;
 
 extern time_t program_start;
@@ -237,11 +233,11 @@ int main(int argc, char **argv){
 	reset_cgi_vars();
 
 	/* read the CGI configuration file */
-	result=read_cgi_config_file(DEFAULT_CGI_CONFIG_FILE);
+	result=read_cgi_config_file(get_cgi_config_location());
 	if(result==ERROR){
 		document_header(FALSE);
 		if(create_type==CREATE_HTML)
-			cgi_config_file_error(DEFAULT_CGI_CONFIG_FILE);
+			cgi_config_file_error(get_cgi_config_location());
 		document_footer();
 		return ERROR;
 	        }
@@ -273,7 +269,7 @@ int main(int argc, char **argv){
                 }
 
 	/* read all status data */
-	result=read_all_status_data(DEFAULT_CGI_CONFIG_FILE,READ_ALL_STATUS_DATA);
+	result=read_all_status_data(get_cgi_config_location(),READ_ALL_STATUS_DATA);
 	if(result==ERROR){
 		document_header(FALSE);
 		if(create_type==CREATE_HTML)
@@ -289,9 +285,6 @@ int main(int argc, char **argv){
 	/* get authentication information */
 	get_authentication_information(&current_authdata);
 
-	/* read in extended host information */
-	read_extended_object_config_data(DEFAULT_CGI_CONFIG_FILE,READ_EXTENDED_HOST_INFO);
-
 	/* display the network map... */
 	display_map();
 
@@ -299,7 +292,6 @@ int main(int argc, char **argv){
 
 	/* free all allocated memory */
 	free_memory();
-	free_extended_data();
 	free_layer_list();
 
 	return OK;
@@ -313,19 +305,19 @@ void document_header(int use_stylesheet){
 	time_t expire_time;
 
 	if(create_type==CREATE_HTML){
-		printf("Cache-Control: no-store\n");
-		printf("Pragma: no-cache\n");
-		printf("Refresh: %d\n",refresh_rate);
+		printf("Cache-Control: no-store\r\n");
+		printf("Pragma: no-cache\r\n");
+		printf("Refresh: %d\r\n",refresh_rate);
 
 		time(&current_time);
 		get_time_string(&current_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Last-Modified: %s\n",date_time);
+		printf("Last-Modified: %s\r\n",date_time);
 
 		expire_time=0L;
 		get_time_string(&expire_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Expires: %s\n",date_time);
+		printf("Expires: %s\r\n",date_time);
 
-		printf("Content-Type: text/html\n\n");
+		printf("Content-Type: text/html\r\n\r\n");
 
 		if(embedded==TRUE)
 			return;
@@ -336,8 +328,10 @@ void document_header(int use_stylesheet){
 		printf("Network Map\n");
 		printf("</title>\n");
 
-		if(use_stylesheet==TRUE)
+		if(use_stylesheet==TRUE){
+			printf("<LINK REL='stylesheet' TYPE='text/css' HREF='%s%s'>\n",url_stylesheets_path,COMMON_CSS);
 			printf("<LINK REL='stylesheet' TYPE='text/css' HREF='%s%s'>\n",url_stylesheets_path,STATUSMAP_CSS);
+		        }
 
 		/* write JavaScript code for popup window */
 		write_popup_code();
@@ -353,18 +347,18 @@ void document_header(int use_stylesheet){
 	        }
 
 	else{
-		printf("Cache-Control: no-store\n");
-		printf("Pragma: no-cache\n");
+		printf("Cache-Control: no-store\r\n");
+		printf("Pragma: no-cache\r\n");
 
 		time(&current_time);
 		get_time_string(&current_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Last-Modified: %s\n",date_time);
+		printf("Last-Modified: %s\r\n",date_time);
 
 		expire_time=(time_t)0L;
 		get_time_string(&expire_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Expires: %s\n",date_time);
+		printf("Expires: %s\r\n",date_time);
 
-		printf("Content-Type: image/png\n\n");
+		printf("Content-Type: image/png\r\n\r\n");
 	        }
 
 	return;
@@ -682,7 +676,7 @@ void display_page_header(void){
 					printf("&scaling_factor=%2.1f",user_scaling_factor);
 				print_layer_url(TRUE);
 				printf("'>");
-				printf("<img src='%s%s' border=0 alt='%d'></a></td>\n",url_images_path,(current_zoom_granularity==zoom)?ZOOM2_ICON:ZOOM1_ICON,zoom);
+				printf("<img src='%s%s' border=0 alt='%d' title='%d'></a></td>\n",url_images_path,(current_zoom_granularity==zoom)?ZOOM2_ICON:ZOOM1_ICON,zoom,zoom);
 		                }
 
 			printf("<td valign=center class='zoomTitle'>&nbsp;&nbsp;Zoom In</td>\n");
@@ -774,7 +768,7 @@ void display_page_header(void){
 		printf("</td></tr>\n");
 
 		printf("<tr><td CLASS='optBoxItem'>\n");
-		printf("Supress popups:<br>\n");
+		printf("Suppress popups:<br>\n");
 		printf("<input type='checkbox' name='nopopups' %s>\n",(display_popups==FALSE)?"CHECKED":"");
 		printf("</td><td CLASS='optBoxItem'>\n");
 		printf("<input type='submit' value='Update'>\n");
@@ -870,7 +864,6 @@ void calculate_host_coords(void){
 	int layer_members=0;
 	int current_layer_member=0;
 	int max_drawing_width=0;
-	int x=0;
   
 
 	/******************************/
@@ -905,7 +898,7 @@ void calculate_host_coords(void){
 
 		/* none was found, so add a blank one */
 		if(temp_hostextinfo==NULL)
-			add_extended_host_info(temp_host->name,NULL,NULL,NULL,NULL,NULL,0,0,0.0,0.0,0.0,0,0);
+			add_hostextinfo(temp_host->name,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0,0,0.0,0.0,0.0,0,0);
 	        }
 
 
@@ -916,7 +909,7 @@ void calculate_host_coords(void){
 		if(show_all_hosts==TRUE)
 			this_host=NULL;
 		else
-			this_host=find_host(host_name,NULL);
+			this_host=find_host(host_name);
 
 		/* find total number of immediate parents/children for this host */
 		child_hosts=number_of_immediate_child_hosts(this_host);
@@ -947,7 +940,7 @@ void calculate_host_coords(void){
 		for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 			/* find the host that matches this entry */
-			temp_host=find_host(temp_hostextinfo->host_name,NULL);
+			temp_host=find_host(temp_hostextinfo->host_name);
 
 			if(temp_host==NULL)
 				continue;
@@ -1003,7 +996,7 @@ void calculate_host_coords(void){
 		if(show_all_hosts==TRUE)
 			this_host=NULL;
 		else
-			this_host=find_host(host_name,NULL);
+			this_host=find_host(host_name);
 		*/
 
 		/* always use NULL as the "main" host, screen coords/dimensions are adjusted automatically */
@@ -1037,7 +1030,7 @@ void calculate_host_coords(void){
 		for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 			/* find the host that matches this entry */
-			temp_host=find_host(temp_hostextinfo->host_name,NULL);
+			temp_host=find_host(temp_hostextinfo->host_name);
 
 			if(temp_host==NULL)
 				continue;
@@ -1084,7 +1077,7 @@ void calculate_host_coords(void){
 			for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 				/* find the host that matches this entry */
-				temp_host=find_host(temp_hostextinfo->host_name,NULL);
+				temp_host=find_host(temp_hostextinfo->host_name);
 
 				if(temp_host==NULL)
 					continue;
@@ -1114,7 +1107,7 @@ void calculate_host_coords(void){
 		if(show_all_hosts==TRUE)
 			this_host=NULL;
 		else
-			this_host=find_host(host_name,NULL);
+			this_host=find_host(host_name);
 		*/
 		
 		/* always use NULL as the "main" host, screen coords/dimensions are adjusted automatically */
@@ -1148,7 +1141,7 @@ void calculate_host_coords(void){
 		for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 			/* find the host that matches this entry */
-			temp_host=find_host(temp_hostextinfo->host_name,NULL);
+			temp_host=find_host(temp_hostextinfo->host_name);
 
 			if(temp_host==NULL)
 				continue;
@@ -1362,7 +1355,7 @@ void find_eligible_hosts(void){
 	for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 		/* find the host */
-		temp_host=find_host(temp_hostextinfo->host_name,NULL);
+		temp_host=find_host(temp_hostextinfo->host_name);
 
 		if(temp_host==NULL)
 			temp_hostextinfo->should_be_drawn=FALSE;
@@ -1496,7 +1489,7 @@ void draw_host_links(void){
 		return;
 
 	/* find the "main" host we're drawing */
-	main_host=find_host(host_name,NULL);
+	main_host=find_host(host_name);
 	if(show_all_hosts==TRUE)
 		main_host=NULL;
 
@@ -1504,7 +1497,7 @@ void draw_host_links(void){
 	for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 		/* find the config entry for this host */
-		this_host=find_host(temp_hostextinfo->host_name,NULL);
+		this_host=find_host(temp_hostextinfo->host_name);
 		if(this_host==NULL)
 			continue;
 
@@ -1570,7 +1563,7 @@ void draw_host_links(void){
 				continue;
 
 			/* find the parent host config entry */
-			parent_host=find_host(temp_parent_hostextinfo->host_name,NULL);
+			parent_host=find_host(temp_parent_hostextinfo->host_name);
 			if(parent_host==NULL)
 				continue;
 
@@ -1697,7 +1690,7 @@ void draw_hosts(void){
 			continue;
 
 		/* find the host */
-		temp_host=find_host(temp_hostextinfo->host_name,NULL);
+		temp_host=find_host(temp_hostextinfo->host_name);
 
 		/* is this host in the layer inclusion/exclusion list? */
 		in_layer_list=is_host_in_layer_list(temp_host);
@@ -1811,7 +1804,7 @@ void draw_hosts(void){
 			                }
 
 
-				if(temp_hostextinfo->gd2_icon_image!=NULL)
+				if(temp_hostextinfo->statusmap_image!=NULL)
 					has_image=TRUE;
 				else
 					has_image=FALSE;
@@ -1820,7 +1813,7 @@ void draw_hosts(void){
 				if(has_image==TRUE){
 
 				        /* get the name of the image file to open for the logo */
-					snprintf(image_input_file,sizeof(image_input_file)-1,"%s%s",physical_logo_images_path,temp_hostextinfo->gd2_icon_image);
+					snprintf(image_input_file,sizeof(image_input_file)-1,"%s%s",physical_logo_images_path,temp_hostextinfo->statusmap_image);
 					image_input_file[sizeof(image_input_file)-1]='\x0';
 
 				        /* read in the logo image from file... */
@@ -1879,7 +1872,7 @@ void draw_hosts(void){
 			if(display_popups==TRUE){
 
 				printf("onMouseOver='showPopup(\"");
-				write_host_popup_text(find_host(temp_hostextinfo->host_name,NULL));
+				write_host_popup_text(find_host(temp_hostextinfo->host_name));
 				printf("\",event)' onMouseOut='hidePopup()'");
 			        }
 
@@ -1913,8 +1906,6 @@ void draw_host_text(char *name,int x,int y){
 	hoststatus *temp_hoststatus;
 	int status_color=color_black;
 	char temp_buffer[MAX_INPUT_BUFFER];
-	int string_width=0;
-	int string_height=0;
 
 	if(use_text==FALSE)
 		return;
@@ -1955,7 +1946,7 @@ void draw_host_text(char *name,int x,int y){
 
 		temp_buffer[sizeof(temp_buffer)-1]='\x0';
 
-		/* write the host status string to the generated imate... */
+		/* write the host status string to the generated image... */
 		draw_text(temp_buffer,x,y+gdFontSmall->h,status_color);
                 }
 
@@ -1991,7 +1982,7 @@ void write_host_popup_text(host *hst){
 	        }
 
 	/* strip nasty stuff from plugin output */
-	sanitize_plugin_output(temp_status->information);
+	sanitize_plugin_output(temp_status->plugin_output);
 
 	printf("<table border=0 cellpadding=0 cellspacing=5>");
 
@@ -2028,7 +2019,7 @@ void write_host_popup_text(host *hst){
 		printf("Pending");
 
 	printf("</b></td></tr>");
-	printf("<tr><td class=\\\"popupText\\\">Status Information:</td><td class=\\\"popupText\\\"><b>%s</b></td></tr>",temp_status->information);
+	printf("<tr><td class=\\\"popupText\\\">Status Information:</td><td class=\\\"popupText\\\"><b>%s</b></td></tr>",(temp_status->plugin_output==NULL)?"":temp_status->plugin_output);
 
 	current_time=time(NULL);
 	if(temp_status->last_state_change==(time_t)0)
@@ -2062,10 +2053,10 @@ void write_host_popup_text(host *hst){
 
 	printf("<br><b><u>Services:</u></b><br>");
 
-	service_totals=get_servicestatus_count(hst->name,SERVICE_OK)+get_servicestatus_count(hst->name,SERVICE_RECOVERY);
+	service_totals=get_servicestatus_count(hst->name,SERVICE_OK);
 	if(service_totals>0)
 		printf("- <font color=green>%d ok</font><br>",service_totals);
-	service_totals=get_servicestatus_count(hst->name,SERVICE_CRITICAL)+get_servicestatus_count(hst->name,SERVICE_UNREACHABLE)+get_servicestatus_count(hst->name,SERVICE_HOST_DOWN);
+	service_totals=get_servicestatus_count(hst->name,SERVICE_CRITICAL);
 	if(service_totals>0)
 		printf("- <font color=red>%d critical</font><br>",service_totals);
 	service_totals=get_servicestatus_count(hst->name,SERVICE_WARNING);
@@ -2323,6 +2314,7 @@ void write_popup_code(void){
 	printf("document.popup.style.left = (document.all ? eventObj.x : eventObj.layerX) + %d;\n",x_offset);
 	printf("document.popup.style.top  = (document.all ? eventObj.y : eventObj.layerY) + %d;\n",y_offset);
 	*/
+
 	printf("document.popup.style.visibility = \"visible\";\n");
 	printf("} \n");
  
@@ -2425,7 +2417,7 @@ int is_host_in_layer_list(host *hst){
 	for(temp_layer=layer_list;temp_layer!=NULL;temp_layer=temp_layer->next){
 
 		/* find the hostgroup */
-		temp_hostgroup=find_hostgroup(temp_layer->layer_name,NULL);
+		temp_hostgroup=find_hostgroup(temp_layer->layer_name);
 		if(temp_hostgroup==NULL)
 			continue;
 		
@@ -2508,7 +2500,7 @@ int number_of_host_layer_members(host *parent, int layer){
 	host *temp_host;
 
 	for(temp_host=host_list;temp_host!=NULL;temp_host=temp_host->next){
-		
+
 		current_layer=host_child_depth_separation(parent,temp_host);
 
 		if(current_layer==layer)
@@ -2547,6 +2539,7 @@ int max_child_host_drawing_width(host *parent){
 	host *temp_host;
 	int child_width=0;
 
+
 	for(temp_host=host_list;temp_host!=NULL;temp_host=temp_host->next){
 		
 		if(is_host_immediate_child_of_host(parent,temp_host)==TRUE)
@@ -2638,8 +2631,6 @@ void calculate_circular_coords(void){
 	int min_y=0;
 	int have_min_x=FALSE;
 	int have_min_y=FALSE;
-	int max_y=0;
-	int have_max_y=FALSE;
 	hostextinfo *temp_hostextinfo;
 
 	/* calculate all host coords, starting with first layer */
