@@ -2,8 +2,8 @@
  *
  * STATUSWRL.C - Nagios 3-D (VRML) Network Status View
  *
- * Copyright (c) 1999-2002 Ethan Galstad (nagios@nagios.org)
- * Last Modified:   10-22-2002
+ * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
+ * Last Modified: 03-27-2006
  *
  * Description:
  *
@@ -13,9 +13,8 @@
  * License:
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
- * (at your option) any later version.
+ * it under the terms of the GNU General Public License version 2 as
+ * published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -28,25 +27,25 @@
  *
  *****************************************************************************/
 
-#include "../common/config.h"
-#include "../common/locations.h"
-#include "../common/common.h"
-#include "../common/objects.h"
-#include "../common/statusdata.h"
+#include "../include/config.h"
+#include "../include/common.h"
+#include "../include/objects.h"
+#include "../include/statusdata.h"
 
-#include "cgiutils.h"
-#include "getcgi.h"
-#include "auth.h"
-#include "edata.h"
+#include "../include/cgiutils.h"
+#include "../include/getcgi.h"
+#include "../include/cgiauth.h"
 
 extern char main_config_file[MAX_FILENAME_LENGTH];
 extern char url_html_path[MAX_FILENAME_LENGTH];
 extern char url_images_path[MAX_FILENAME_LENGTH];
+extern char url_logo_images_path[MAX_FILENAME_LENGTH];
 
 extern char *statuswrl_include;
 
+extern host *host_list;
+extern service *service_list;
 extern hostextinfo *hostextinfo_list;
-extern host        *host_list;
 
 extern int default_statuswrl_layout_method;
 
@@ -89,7 +88,6 @@ void calculate_balanced_tree_coords(host *,int,int);
 void calculate_circular_coords(void);
 void calculate_circular_layer_coords(host *,double,double,int,int);
 
-char url_logo_images_path[MAX_FILENAME_LENGTH];
 
 authdata current_authdata;
 
@@ -143,7 +141,7 @@ int main(int argc, char **argv){
 	reset_cgi_vars();
 
 	/* read the CGI configuration file */
-	result=read_cgi_config_file(DEFAULT_CGI_CONFIG_FILE);
+	result=read_cgi_config_file(get_cgi_config_location());
 	if(result==ERROR){
 		document_header();
 		return ERROR;
@@ -168,7 +166,7 @@ int main(int argc, char **argv){
 		return ERROR;
 
 	/* read all status data */
-	result=read_all_status_data(DEFAULT_CGI_CONFIG_FILE,READ_ALL_STATUS_DATA);
+	result=read_all_status_data(get_cgi_config_location(),READ_ALL_STATUS_DATA);
 	if(result==ERROR){
 		free_memory();
 		return ERROR;
@@ -177,15 +175,11 @@ int main(int argc, char **argv){
 	/* get authentication information */
 	get_authentication_information(&current_authdata);
 
-	/* read in extended host information */
-	read_extended_object_config_data(DEFAULT_CGI_CONFIG_FILE,READ_EXTENDED_HOST_INFO);
-
 	/* display the 3-D VRML world... */
 	display_world();
 
 	/* free all allocated memory */
 	free_memory();
-	free_extended_data();
 
 	return OK;
         }
@@ -198,18 +192,18 @@ void document_header(void){
 	time_t expire_time;
 
 
-	printf("Cache-Control: no-store\n");
-	printf("Pragma: no-cache\n");
+	printf("Cache-Control: no-store\r\n");
+	printf("Pragma: no-cache\r\n");
 
 	time(&current_time);
 	get_time_string(&current_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-	printf("Last-Modified: %s\n",date_time);
+	printf("Last-Modified: %s\r\n",date_time);
 
 	expire_time=0L;
 	get_time_string(&expire_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-	printf("Expires: %s\n",date_time);
+	printf("Expires: %s\r\n",date_time);
 
-	printf("Content-Type: x-world/x-vrml\n\n");
+	printf("Content-Type: x-world/x-vrml\r\n\r\n");
 
 	return;
         }
@@ -441,7 +435,7 @@ int number_of_host_layer_members(host *parent, int layer){
 	host *temp_host;
 
 	for(temp_host=host_list;temp_host!=NULL;temp_host=temp_host->next){
-		
+
 		current_layer=host_child_depth_separation(parent,temp_host);
 
 		if(current_layer==layer)
@@ -481,7 +475,6 @@ int max_child_host_drawing_width(host *parent){
 	int child_width=0;
 
 	for(temp_host=host_list;temp_host!=NULL;temp_host=temp_host->next){
-		
 		if(is_host_immediate_child_of_host(parent,temp_host)==TRUE)
 			child_width+=max_child_host_drawing_width(temp_host);
 	        }
@@ -506,10 +499,8 @@ void calculate_host_coords(void){
 	hostextinfo *temp_hostextinfo;
 	host *this_host;
 	host *temp_host;
-	int child_hosts=0;
 	int parent_hosts=0;
 	int max_layer_width=1;
-	int current_child_host=0;
 	int current_parent_host=0;
 	int center_x=0;
 	int offset_x=DEFAULT_NODE_WIDTH/2;
@@ -518,7 +509,6 @@ void calculate_host_coords(void){
 	int layer_members=0;
 	int current_layer_member=0;
 	int max_drawing_width=0;
-	int x=0;
   
 
 	/******************************/
@@ -552,7 +542,7 @@ void calculate_host_coords(void){
 
 		/* none was found, so add a blank one */
 		if(temp_hostextinfo==NULL)
-			add_extended_host_info(temp_host->name,NULL,NULL,NULL,NULL,NULL,0,0,0.0,0.0,0.0,0,0);
+			add_hostextinfo(temp_host->name,NULL,NULL,NULL,NULL,NULL,NULL,NULL,0,0,0.0,0.0,0.0,0,0);
 
 		/* default z coord should 0 for auto-layout modes unless overridden later */
 		else
@@ -592,7 +582,7 @@ void calculate_host_coords(void){
 		for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 			/* find the host that matches this entry */
-			temp_host=find_host(temp_hostextinfo->host_name,NULL);
+			temp_host=find_host(temp_hostextinfo->host_name);
 
 			if(temp_host==NULL)
 				continue;
@@ -639,7 +629,7 @@ void calculate_host_coords(void){
 			for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 				/* find the host that matches this entry */
-				temp_host=find_host(temp_hostextinfo->host_name,NULL);
+				temp_host=find_host(temp_hostextinfo->host_name);
 
 				if(temp_host==NULL)
 					continue;
@@ -693,7 +683,7 @@ void calculate_host_coords(void){
 		for(temp_hostextinfo=hostextinfo_list;temp_hostextinfo!=NULL;temp_hostextinfo=temp_hostextinfo->next){
 
 			/* find the host that matches this entry */
-			temp_host=find_host(temp_hostextinfo->host_name,NULL);
+			temp_host=find_host(temp_hostextinfo->host_name);
 
 			if(temp_host==NULL)
 				continue;
@@ -776,7 +766,7 @@ void calculate_world_bounds(void){
 		else if(temp_hostextinfo->y_3d > max_y_coord)
 			max_y_coord=temp_hostextinfo->y_3d;
 		if(temp_hostextinfo->z_3d < min_z_coord)
-			min_x_coord=temp_hostextinfo->z_3d;
+			min_z_coord=temp_hostextinfo->z_3d;
 		else if(temp_hostextinfo->z_3d > max_z_coord)
 			max_z_coord=temp_hostextinfo->z_3d;
 
@@ -949,7 +939,7 @@ void draw_host(hostextinfo *temp_hostextinfo){
 	        }
 
 	/* find the config entry for this host */
-	temp_host=find_host(temp_hostextinfo->host_name,NULL);
+	temp_host=find_host(temp_hostextinfo->host_name);
 	if(temp_host==NULL)
 		return;
 
@@ -1073,7 +1063,7 @@ void draw_host_links(void){
 		if(child_hostextinfo->have_3d_coords==FALSE)
 			continue;
 
-		child_host=find_host(child_hostextinfo->host_name,NULL);
+		child_host=find_host(child_hostextinfo->host_name);
 		if(child_host==NULL)
 			continue;
 
@@ -1146,8 +1136,6 @@ void draw_host_link(host *hst,double x0, double y0, double z0, double x1, double
 /* draw process icon */
 void draw_process_icon(void){
 	hostextinfo *child_hostextinfo;
-	hostextinfo *parent_hostextinfo;
-	host *parent_host;
 	host *child_host;
 
 	if(draw_nagios_icon==FALSE)
@@ -1200,7 +1188,7 @@ void draw_process_icon(void){
 		if(child_hostextinfo->have_3d_coords==FALSE)
 			continue;
 
-		child_host=find_host(child_hostextinfo->host_name,NULL);
+		child_host=find_host(child_hostextinfo->host_name);
 		if(child_host==NULL)
 			continue;
 
