@@ -3,7 +3,7 @@
  * TRENDS.C -  Nagios State Trends CGI
  *
  * Copyright (c) 1999-2006 Ethan Galstad (nagios@nagios.org)
- * Last Modified: 01-20-2006
+ * Last Modified: 03-21-2006
  *
  * License:
  * 
@@ -1099,18 +1099,18 @@ void document_header(int use_stylesheet){
 	time_t expire_time;
 
 	if(mode==CREATE_HTML){
-		printf("Cache-Control: no-store\n");
-		printf("Pragma: no-cache\n");
+		printf("Cache-Control: no-store\r\n");
+		printf("Pragma: no-cache\r\n");
 
 		time(&current_time);
 		get_time_string(&current_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Last-Modified: %s\n",date_time);
+		printf("Last-Modified: %s\r\n",date_time);
 
 		expire_time=(time_t)0;
 		get_time_string(&expire_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Expires: %s\n",date_time);
+		printf("Expires: %s\r\n",date_time);
 
-		printf("Content-type: text/html\n\n");
+		printf("Content-type: text/html\r\n\r\n");
 
 		if(embedded==TRUE)
 			return;
@@ -1141,18 +1141,18 @@ void document_header(int use_stylesheet){
 	        }
 
 	else{
-		printf("Cache-Control: no-store\n");
-		printf("Pragma: no-cache\n");
+		printf("Cache-Control: no-store\r\n");
+		printf("Pragma: no-cache\r\n");
 
 		time(&current_time);
 		get_time_string(&current_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Last-Modified: %s\n",date_time);
+		printf("Last-Modified: %s\r\n",date_time);
 
 		expire_time=(time_t)0L;
 		get_time_string(&expire_time,date_time,sizeof(date_time),HTTP_DATE_TIME);
-		printf("Expires: %s\n",date_time);
+		printf("Expires: %s\r\n",date_time);
 
-		printf("Content-Type: image/png\n\n");
+		printf("Content-Type: image/png\r\n\r\n");
 	        }
 
 	return;
